@@ -2,7 +2,4 @@ TOKEN_START_OF_TRACE = 'SOT'
 TOKEN_END_OF_TRACE = 'EOT'
 TOKEN_DEFAULT = 'Other'
 
-TOKEN_END_OF_FILE = 'EOF'
-
-METHOD_CLASSIC = 101
-METHOD_CLASSIC_LARGE_SPARSE = 102
+TOKEN_END_OF_STREAM = 'EOS'
