@@ -43,10 +43,13 @@ class BaseMethod:
         raise NotImplementedError
 
     def get_next_data(self):
+        """
+        get event from input stream.
+        """
         data = self._input_stream.get()
 
         # end of file is reached
-        if data[0] == const.TOKEN_END_OF_TRACE:
+        if data[0] == const.TOKEN_END_OF_STREAM:
             self.send_data(data)
             self.finished = True
             return None
@@ -54,4 +57,8 @@ class BaseMethod:
             return data
 
     def send_data(self, data):
+        """
+        send data to output stream.
+        :param data:
+        """
         self._output_stream.put(data)
